@@ -35,7 +35,8 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
             os.mkdir('CapturedImages/sequenceImages/undistortRadioCalib/radioCalibResults/')
         if not os.path.exists('CapturedImages/sequenceImages/undistortRadioCalib/undistortResults/'):
             os.mkdir('CapturedImages/sequenceImages/undistortRadioCalib/undistortResults/')
-        
+        if not os.path.exists('CalibrationImages/RadiometricTest/'):
+            os.mkdir('CalibrationImages/RadiometricTest/')
         if not os.path.exists('CalibrationImages/DisplayRadiometric'):
             os.mkdir('CalibrationImages/DisplayRadiometric')
             
@@ -62,7 +63,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         # plt.show()
         fig.savefig(imgSave + '/Display to Relative Radiance Curve' + '.png')
         # fig.savefig('Display to Relative Radiance Curve.png')
-        return DisplayToRadianceData
+        return DisplayToRadianceData, pixelValues
 
     def calUpValue(self, imgPath):
         img = cv2.imread(imgPath, cv2.IMREAD_GRAYSCALE)
@@ -86,7 +87,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         # img = np.array(img, dtype='uint8')
         # row, col = img.shape[0], img.shape[1]
 
-        DisplayToRadianceData = self.calculateDisplayCalibration()
+        DisplayToRadianceData, pixelValues = self.calculateDisplayCalibration()
         DisplayToRadianceValue = DisplayToRadianceData[255]
         
         # arr = []
@@ -110,7 +111,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         # plt.savefig('Reflectivity Map.png')
 
         Reflectivity = np.array(arr)
-        return Reflectivity
+        return Reflectivity, DisplayToRadianceData, pixelValues
 
     def radiometricCalibUndistortImages(self):
         Reflectivity = self.calculateReflectivity()
@@ -207,8 +208,8 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         
         if not os.path.exists('CalibrationNumpyData/'):
             os.mkdir('CalibrationNumpyData/')
-        if not os.path.exists('CalibrationNumpyData/DisplayRadiometric/'):
-            os.mkdir('CalibrationNumpyData/DisplayRadiometric/')
+        if not os.path.exists('CalibrationImages/RadiometricTest/'):
+            os.mkdir('CalibrationImages/RadiometricTest/')
        
         pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH))
         for i in range(DISPLAY_WIDTH):
@@ -216,14 +217,17 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         
         cv2.imshow(window_name, pattern.astype(np.uint8))
         cv2.waitKey(40)
-        self.camera.getImage(name = 'DisplayRadiometric/'+ 'testImage', calibration=True)
+        self.camera.getImage(name = 'RadiometricTest/'+ 'testImage', calibration=True)
         
-        print('Capture Complete! Test image viewable at CalibrationImages/DisplayRadiometric/')
+        print('Capture Complete! Test image viewable at CalibrationImages/RadiometricTest/')
         cv2.waitKey(1000)
         cv2.destroyAllWindows()
         cv2.waitKey(1)
         cv2.waitKey(1)
-
+        
+        
+        
+        
     def avgImagePixel(self):
         pixelValues = []
         files = []
